{% extends "admin/base_site.html" %} {% load i18n admin_urls %} {% load static %} {% load extra_tags %} {% block extrastyle %} {% endblock %} {% block breadcrumbs %}
{% endblock %} {% block content %}
{% if action_list %} {% regroup action_list by transacted_on as actions %}

{% trans 'Date/time' %} | {% trans 'User' %} | {% trans 'Action' %} | {% trans 'Field' %} | {% trans 'Previous Value' %} | {% trans 'New Value' %}
--- | --- | --- | --- | --- | ---
{% for action in actions %} {% for act in action.list %}
{% ifchanged action.grouper %}{{ action.grouper|date:"DATETIME_FORMAT" }} {% endifchanged %} {% ifchanged act.transacted_by %} | {{ act.transacted_by }} {% endifchanged %} {% ifchanged act.transactoin_type %} | {{ act.transaction_type|get_full_name }} {% endifchanged %} | {{ act.field_name }} | {{ act.previous_val|render:act.previous_val_type }} | {{ act.current_val|render:act.current_val_type }}
{% endfor %} {% endfor %}

{% else %}

{% trans "This object doesn't have a change history." %}

{% endif %}

{% if action_list.number|add:"-5" > 0 %} 1 {% endif %} {% if action_list.number|add:"-5" > 1 %} … {% endif %} {% for page_num in action_list.paginator.page_range %} {% if action_list.number == page_num %} {{ page_num }} {% else %} {% if page_num > action_list.number|add:"-5" and page_num < action_list.number|add:"5" %} {{ page_num }} {% endif %} {% endif %} {% endfor %} {% if action_list.number|add:"5" < action_list.paginator.num_pages %} … {% endif %} {% if action_list.number|add:"4" < action_list.paginator.num_pages %} {{ action_list.paginator.num_pages }} {% endif %} {{ action_list.paginator.count }} changes

{% endblock %}